@@ -179,7 +179,13 @@ def autoinvoke(method: Callable[..., _T], keywords: dict) -> _T:
     return method(*posargs, *varargs, **kwdargs)
 
 
-def entropy(data: bytearray) -> float:
+def entropy_fallback(data: ByteString) -> float:
+    histogram = {b: data.count(b) for b in range(0x100)}
+    S = [histogram[b] / len(data) for b in histogram]
+    return 0.0 + -sum(p * log(p, 2) for p in S if p) / 8.0
+
+
+def entropy(data: ByteString) -> float:
     """
     Computes the entropy of `data` over the alphabet of all bytes.
     """
@@ -188,14 +194,11 @@ def entropy(data: bytearray) -> float:
     try:
         import numpy
     except ImportError:
-        histogram = {b: data.count(b) for b in range(0x100)}
-        S = [histogram[b] / len(data) for b in histogram]
-        return 0.0 + -sum(p * log(p, 2) for p in S if p) / 8.0
-    else:
-        _, counts = numpy.unique(data, return_counts=True)
-        probs = counts / len(data)
-        # 8 bits are the maximum number of bits of information in a byte
-        return 0.0 + -sum(p * log(p, 2) for p in probs) / 8.0
+        return entropy_fallback(data)
+    _, counts = numpy.unique(memoryview(data), return_counts=True)
+    probs = counts / len(data)
+    # 8 bits are the maximum number of bits of information in a byte
+    return 0.0 + -sum(p * log(p, 2) for p in probs) / 8.0
 
 
 def index_of_coincidence(data: bytearray) -> float:
